@@ -8,6 +8,7 @@
 #include <QVector>
 
 #include "database.h"
+#include "debug.h"
 #include "entriesmodel.h"
 #include "fetcher.h"
 
@@ -16,10 +17,7 @@ EntriesModel::EntriesModel(QObject *parent)
 {
     connect(&Fetcher::instance(), &Fetcher::feedUpdated, this, [this](const QString &url) {
         if (m_feedUrl.isEmpty() || m_feedUrl == url) {
-            beginResetModel();
-            m_entries.clear();
             loadEntries();
-            endResetModel();
         }
     });
     connect(&Database::instance(), &Database::entryReadChanged, this, [this](const QString &entryId, bool read) {
@@ -31,6 +29,18 @@ EntriesModel::EntriesModel(QObject *parent)
             }
         }
     });
+    connect(&Database::instance(), &Database::feedReadChanged, this, [this]() {
+        loadEntries();
+    });
+    connect(&Database::instance(), &Database::entryFavoriteChanged, this, [this](const QString &entryId, bool favorite) {
+        for (auto i = 0; i < m_entries.size(); i++) {
+            if (m_entries[i].id == entryId) {
+                m_entries[i].favorite = favorite;
+                dataChanged(index(i, 0), index(i, 0), {FavoritesRole});
+                break;
+            }
+        }
+    });
     loadEntries();
 }
 
@@ -49,6 +59,9 @@ QVariant EntriesModel::data(const QModelIndex &index, int role) const
     if (role == ContentRole) {
         return entry.content;
     }
+    if (role == FeedTitleRole) {
+        return entry.feedTitle;
+    }
     if (role == AuthorsRole) {
         return entry.authors;
     }
@@ -64,6 +77,9 @@ QVariant EntriesModel::data(const QModelIndex &index, int role) const
     if (role == BaseUrlRole) {
         return QUrl(entry.link).adjusted(QUrl::RemovePath).toString();
     }
+    if (role == FavoritesRole) {
+        return entry.favorite;
+    }
     return QVariant();
 }
 
@@ -74,12 +90,14 @@ QHash<int, QByteArray> EntriesModel::roleNames() const
         {ReadRole, "read"},
         {TitleRole, "title"},
         {ContentRole, "content"},
+        {FeedTitleRole, "feedTitle"},
         {AuthorsRole, "authors"},
         {CreatedRole, "created"},
         {UpdatedRole, "updated"},
         {LinkRole, "link"},
         {BaseUrlRole, "baseUrl"},
         {ReadRole, "read"},
+        {FavoritesRole, "favorite"},
     };
 }
 
@@ -95,7 +113,7 @@ int EntriesModel::rowCount(const QModelIndex &parent) const
     }
     Database::instance().execute(query);
     if (!query.next()) {
-        qWarning() << "Failed to query feed count";
+        qCWarning(ALLIGATOR) << "Failed to query feed count";
     }
     return query.value(0).toInt();
 }
@@ -129,6 +147,15 @@ void EntriesModel::loadEntries()
             entry.authors = authorList[0];
         }
 
+        QSqlQuery feedQuery;
+        feedQuery.prepare(QStringLiteral("SELECT * FROM Feeds WHERE url=:feed"));
+        feedQuery.bindValue(QStringLiteral(":feed"), entryQuery.value(QStringLiteral("feed")).toString());
+        Database::instance().execute(feedQuery);
+        feedQuery.next();
+        QString name = feedQuery.value(QStringLiteral("name")).toString();
+        QString displayName = feedQuery.value(QStringLiteral("displayName")).toString();
+        entry.feedTitle = !displayName.isEmpty() ? displayName : name;
+
         entry.created.setSecsSinceEpoch(entryQuery.value(QStringLiteral("created")).toInt());
         entry.updated.setSecsSinceEpoch(entryQuery.value(QStringLiteral("updated")).toInt());
         entry.id = entryQuery.value(QStringLiteral("id")).toString();
@@ -136,6 +163,7 @@ void EntriesModel::loadEntries()
         entry.content = entryQuery.value(QStringLiteral("content")).toString();
         entry.link = entryQuery.value(QStringLiteral("link")).toString();
         entry.read = entryQuery.value(QStringLiteral("read")).toBool();
+        entry.favorite = entryQuery.value((QStringLiteral("favorite"))).toBool();
 
         m_entries.append(entry);
     }
