@@ -17,11 +17,13 @@ struct Entry {
     QString id;
     QString title;
     QString content;
+    QString feedTitle;
     QString authors;
     QDateTime created;
     QDateTime updated;
     QString link;
     bool read;
+    bool favorite;
 };
 
 class EntriesModel : public QAbstractListModel
@@ -36,12 +38,14 @@ public:
         IdRole = Qt::DisplayRole,
         TitleRole,
         ContentRole,
+        FeedTitleRole,
         AuthorsRole,
         CreatedRole,
         UpdatedRole,
         LinkRole,
         BaseUrlRole,
         ReadRole,
+        FavoritesRole,
     };
     Q_ENUM(Roles);
     explicit EntriesModel(QObject *parent = nullptr);
