@@ -27,16 +27,10 @@
 
 #include "alligator-version.h"
 #include "alligatorsettings.h"
-#include "contenthelper.h"
 #include "database.h"
-#include "entriesmodel.h"
-#include "entriesproxymodel.h"
-#include "feedgroupsmodel.h"
-#include "feedsmodel.h"
-#include "feedsproxymodel.h"
-#include "fetcher.h"
 
 #ifdef Q_OS_WINDOWS
+#include "debug.h"
 #include <windows.h>
 #endif
 
@@ -55,16 +49,16 @@ int main(int argc, char *argv[])
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 #endif
-    KColorSchemeManager colorMgr;
+    KColorSchemeManager::instance();
 
 #ifdef Q_OS_WINDOWS
     if (AttachConsole(ATTACH_PARENT_PROCESS)) {
         FILE *outFile = freopen("CONOUT$", "w", stdout);
         if (!outFile)
-            qWarning() << "Failed to reopen stdout";
+            qCWarning(ALLIGATOR) << "Failed to reopen stdout";
         FILE *errFile = freopen("CONOUT$", "w", stderr);
         if (!errFile)
-            qWarning() << "Failed to reopen stderr";
+            qCWarning(ALLIGATOR) << "Failed to reopen stderr";
     }
 
     QApplication::setStyle(QStringLiteral("breeze"));
@@ -87,7 +81,9 @@ int main(int argc, char *argv[])
     about.addAuthor(i18n("Tobias Fella"), QString(), QStringLiteral("tobias.fella@kde.org"), QStringLiteral("https://tobiasfella.de"));
     KAboutData::setApplicationData(about);
 
-    qmlRegisterSingletonInstance("org.kde.alligator.config", 1, 0, "AlligatorSettings", AlligatorSettings::self());
+#ifndef Q_OS_ANDROID
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("alligator")));
+#endif
 
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
